fn validate_public_key<C>(
private_key: &SecretKey<C>,
sec1_bytes: &[u8],
) -> ErrorResultExpand description
Validate the public key in form of uncompressed SEC1 encoded curve point, against a private key.
fn validate_public_key<C>(
private_key: &SecretKey<C>,
sec1_bytes: &[u8],
) -> ErrorResultValidate the public key in form of uncompressed SEC1 encoded curve point, against a private key.